@@ -118,7 +118,7 @@ class IWorkshop(model.Schema):
     directives.widget(license=RadioFieldWidget)
     license = schema.List(
         title=_(safe_unicode('License Of Your Talk')),
-        description=_(safe_unicode('Choose a license for your talk')),
+        description=_(safe_unicode('Choose a license for your workshop')),
         value_type=schema.Choice(source='ContentLicense'),
         required=True,
     )
@@ -126,7 +126,7 @@ class IWorkshop(model.Schema):
     read_permission(conferencetrack='cmf.ReviewPortalContent')
     write_permission(conferencetrack='cmf.ReviewPortalContent')
     conferencetrack = RelationList(
-        title=_(safe_unicode('Choose the track for this talk')),
+        title=_(safe_unicode('Choose the track for this workshop')),
         default=[],
         value_type=RelationChoice(vocabulary='ConferenceTrack'),
         required=False,
@@ -305,7 +305,7 @@ class IWorkshop(model.Schema):
 
     @invariant
     def validateplanedlengthchoosen(data):
-        if not data.call_for_paper_topic:
+        if not data.planedworkshoplength:
             raise ChoosePlanedLength(
                 _(safe_unicode('Please choose a planed length for your workshop.'),
                   ),
@@ -370,8 +370,8 @@ class ValidateWorkshopUniqueness(validator.SimpleFieldValidator):
         if value is not None:
             catalog = api.portal.get_tool(name='portal_catalog')
             results = catalog({'Title': quote_chars(value),
-                               'object_provides':
-                                   IWorkshop.__identifier__})
+                               'portal_type': ('collective.conferences.workshop',
+                                               'collective.conferences.talk')})
             contextUUID = api.content.get_uuid(self.context)
             for result in results:
                 if result.UID != contextUUID:
